@@ -16,6 +16,9 @@ SELECT create_hypertable('uuid_events', 'id', chunk_time_interval => true);
 
 SELECT create_hypertable('uuid_events', 'id', chunk_time_interval => interval '1 day');
 
+SELECT time_interval
+FROM timescaledb_information.dimensions
+WHERE hypertable_name = 'uuid_events';
 
 --
 -- Test that inserting boundary values generates the right constraints
@@ -126,7 +129,7 @@ SELECT uuid_timestamp(id), device, temp
 FROM uuid_events WHERE id < to_uuidv7_boundary(:'chunk_range_start');
 
 SELECT uuid_timestamp(id), device, temp
-FROM uuid_events WHERE id < to_uuidv7_boundary(:'chunk_range_start');
+FROM uuid_events WHERE id < to_uuidv7_boundary(:'chunk_range_start') ORDER BY id;
 
 -- Exclude only one chunk. Add ordering (DESC)
 EXPLAIN (verbose, buffers off, costs off, timing off)
@@ -138,11 +141,84 @@ SELECT uuid_timestamp(id), device, temp
 FROM uuid_events WHERE id < to_uuidv7_boundary(:'chunk_range_end')
 ORDER BY id DESC;
 
+SELECT time_bucket('1 day', id) AS day, avg(temp)
+FROM uuid_events WHERE id < to_uuidv7_boundary(:'chunk_range_end')
+GROUP BY id ORDER BY id DESC;
+
+SELECT time_bucket('1 day', uuid_timestamp(id)) AS day, avg(temp)
+FROM uuid_events WHERE id < to_uuidv7_boundary(:'chunk_range_end')
+GROUP BY id ORDER BY id DESC;
+
+-- Bucket with offset
+SELECT time_bucket('1 day', id, "offset" => '1 week') AS day, avg(temp)
+FROM uuid_events WHERE id < to_uuidv7_boundary(:'chunk_range_end')
+GROUP BY id ORDER BY id DESC;
+
+-- Bucket with origin
+SELECT time_bucket('1 day', id, timestamptz '2000-01-01 00:00') AS day, avg(temp)
+FROM uuid_events WHERE id < to_uuidv7_boundary(:'chunk_range_end')
+GROUP BY id ORDER BY id DESC;
+
+-- Bucket with time zone
+SELECT time_bucket('1 day', id, 'Europe/Stockholm') at time zone 'Europe/Stockholm' as day, avg(temp)
+FROM uuid_events WHERE id < to_uuidv7_boundary(:'chunk_range_end')
+GROUP BY id ORDER BY id DESC;
+
+-- Test NULL arguments
+SELECT time_bucket('1 day', id, 'Europe/Stockholm'::text, NULL::timestamptz) AS day, avg(temp)
+FROM uuid_events WHERE id < to_uuidv7_boundary(:'chunk_range_end')
+GROUP BY id ORDER BY id DESC;
+
+SELECT time_bucket('1 day', id, 'Europe/Stockholm'::text, '2000-01-01 00:00'::timestamptz, NULL::interval) AS day, avg(temp)
+FROM uuid_events WHERE id < to_uuidv7_boundary(:'chunk_range_end')
+GROUP BY id ORDER BY id DESC;
+
+-- Test UUID time_bucket in WHERE clause. Note that there is currently no chunk
+-- exclusion when using time_bucket() in the WHERE clause qual. This requires
+-- special handling of the time_bucket() transform optimizatios for different
+-- operators.
+EXPLAIN (COSTS OFF) SELECT time_bucket('1 day', id) AS day, avg(temp)
+FROM uuid_events WHERE time_bucket('1 day', id) >= :'chunk_range_end'
+GROUP BY id ORDER BY id DESC;
+
+SELECT time_bucket('1 day', id) AS day, avg(temp)
+FROM uuid_events WHERE time_bucket('1 day', id) >= :'chunk_range_end'
+GROUP BY id ORDER BY id DESC;
+
+EXPLAIN (COSTS OFF) SELECT time_bucket('1 day', id) AS day, avg(temp)
+FROM uuid_events WHERE time_bucket('1 day', id) > :'chunk_range_start'
+GROUP BY id ORDER BY id DESC;
+
+SELECT time_bucket('1 day', id) AS day, avg(temp)
+FROM uuid_events WHERE time_bucket('1 day', id) > :'chunk_range_start'
+GROUP BY id ORDER BY id DESC;
+
+EXPLAIN (COSTS OFF) SELECT time_bucket('1 day', id) AS day, avg(temp)
+FROM uuid_events WHERE time_bucket('1 day', id) < :'chunk_range_end'
+GROUP BY id ORDER BY id DESC;
+
+SELECT time_bucket('1 day', id) AS day, avg(temp)
+FROM uuid_events WHERE time_bucket('1 day', id) < :'chunk_range_end'
+GROUP BY id ORDER BY id DESC;
+
+EXPLAIN (COSTS OFF) SELECT time_bucket('1 day', id) AS day, avg(temp)
+FROM uuid_events WHERE time_bucket('1 day', id) <= :'chunk_range_start'
+GROUP BY id ORDER BY id DESC;
+
+SELECT time_bucket('1 day', id) AS day, avg(temp)
+FROM uuid_events WHERE time_bucket('1 day', id) <= :'chunk_range_start'
+GROUP BY id ORDER BY id DESC;
+
+-- Test time_bucket on non-v7 UUID
+\set ON_ERROR_STOP 0
+SELECT time_bucket('1 day', 'ffff0000-0000-4000-8000-000000000000'::uuid);
+\set ON_ERROR_STOP 1
+
 CREATE VIEW chunk_ranges AS
 SELECT
   chunk_name,
-  _timescaledb_functions.to_timestamp(range_start_integer) AS range_start,
-  _timescaledb_functions.to_timestamp(range_end_integer) AS range_end
+  range_start,
+  range_end
 FROM timescaledb_information.chunks
 WHERE hypertable_name = 'uuid_events';
 
