@@ -9,7 +9,7 @@
 #include <access/attnum.h>
 #include <access/tupdesc.h>
 
-#include <nodes/decompress_chunk/compressed_batch.h>
+#include <nodes/columnar_scan/compressed_batch.h>
 
 /*
  * Vector slot functions.
@@ -34,11 +34,6 @@ vector_slot_get_qual_result(const TupleTableSlot *slot, uint16 *num_rows)
  * Return the arrow array or the datum (in case of single scalar value) for a
  * given attribute as a CompressedColumnValues struct.
  */
-static inline const CompressedColumnValues *
-vector_slot_get_compressed_column_values(TupleTableSlot *slot, const AttrNumber attnum)
-{
-	const uint16 offset = AttrNumberGetAttrOffset(attnum);
-	const DecompressBatchState *batch_state = (const DecompressBatchState *) slot;
-	const CompressedColumnValues *values = &batch_state->compressed_columns[offset];
-	return values;
-}
+CompressedColumnValues vector_slot_evaluate_expression(DecompressContext *dcontext,
+													   TupleTableSlot *slot, uint64 const *filter,
+													   const Expr *argument);
