@@ -8,8 +8,6 @@ SET timezone TO PST8PDT;
 
 SELECT _timescaledb_internal.alter_job_set_hypertable_id(0,0);
 SELECT _timescaledb_internal.attach_osm_table_chunk(0,0);
-SELECT _timescaledb_internal.cagg_migrate_plan_exists(0);
-SELECT _timescaledb_internal.cagg_migrate_pre_validation(NULL,NULL,NULL);
 SELECT _timescaledb_internal.cagg_watermark(0);
 SELECT _timescaledb_internal.cagg_watermark_materialized(0);
 SELECT _timescaledb_internal.calculate_chunk_interval(0,0,0);
@@ -33,7 +31,6 @@ SELECT _timescaledb_internal.get_partition_for_key(NULL::text);
 SELECT _timescaledb_internal.get_partition_hash(NULL::text);
 SELECT _timescaledb_internal.hypertable_local_size(NULL,NULL);
 SELECT _timescaledb_internal.interval_to_usec(NULL);
-SELECT _timescaledb_internal.partialize_agg(NULL::text);
 SELECT _timescaledb_internal.policy_compression_check(NULL);
 SELECT _timescaledb_internal.policy_job_stat_history_retention(0,NULL);
 SELECT _timescaledb_internal.policy_job_stat_history_retention_check(NULL);
@@ -56,16 +53,6 @@ SELECT _timescaledb_internal.to_timestamp_without_timezone(0);
 SELECT _timescaledb_internal.to_unix_microseconds(NULL);
 SELECT _timescaledb_internal.tsl_loaded();
 SELECT _timescaledb_internal.unfreeze_chunk(0);
-CALL _timescaledb_internal.cagg_migrate_create_plan(NULL,NULL,true,true);
-CALL _timescaledb_internal.cagg_migrate_execute_copy_data(NULL,NULL);
-CALL _timescaledb_internal.cagg_migrate_execute_copy_policies(NULL,NULL);
-CALL _timescaledb_internal.cagg_migrate_execute_create_new_cagg(NULL,NULL);
-CALL _timescaledb_internal.cagg_migrate_execute_disable_policies(NULL,NULL);
-CALL _timescaledb_internal.cagg_migrate_execute_drop_old_cagg(NULL,NULL);
-CALL _timescaledb_internal.cagg_migrate_execute_enable_policies(NULL,NULL);
-CALL _timescaledb_internal.cagg_migrate_execute_override_cagg(NULL,NULL);
-CALL _timescaledb_internal.cagg_migrate_execute_plan(NULL);
-CALL _timescaledb_internal.cagg_migrate_execute_refresh_new_cagg(NULL,NULL);
 CALL _timescaledb_internal.policy_compression(0,NULL);
 CALL _timescaledb_internal.policy_recompression(0,NULL);
 CALL _timescaledb_internal.policy_refresh_continuous_aggregate(0,NULL);
