@@ -33,14 +33,14 @@ CREATE OR REPLACE FUNCTION insert_job(
        fixed_schedule BOOL DEFAULT false
 ) RETURNS INT LANGUAGE SQL SECURITY DEFINER AS
 $$
-  INSERT INTO _timescaledb_config.bgw_job(application_name,schedule_interval,max_runtime,max_retries,
+  INSERT INTO _timescaledb_catalog.bgw_job(application_name,schedule_interval,max_runtime,max_retries,
   retry_period,proc_name,proc_schema,owner,scheduled,fixed_schedule)
   VALUES($1,$3,$4,5,$5,$2,'public',$6,$7,$8) RETURNING id;
 $$;
 
 CREATE OR REPLACE FUNCTION test_toggle_scheduled(job_id INTEGER) RETURNS VOID LANGUAGE SQL SECURITY DEFINER AS
 $$
-  UPDATE _timescaledb_config.bgw_job SET scheduled = NOT scheduled WHERE id = $1;
+  UPDATE _timescaledb_catalog.bgw_job SET scheduled = NOT scheduled WHERE id = $1;
 $$;
 
 \set WAIT_ON_JOB 0
@@ -82,7 +82,7 @@ DECLARE
   app_name TEXT;
   message TEXT;
 BEGIN
-    SELECT application_name INTO app_name FROM _timescaledb_config.bgw_job WHERE id = job_id;
+    SELECT application_name INTO app_name FROM _timescaledb_catalog.bgw_job WHERE id = job_id;
 
     --wait up to a second checking each 100ms
     FOR i in 1..10
@@ -99,7 +99,7 @@ END
 $BODY$;
 
 -- Remove any default jobs, e.g., telemetry
-DELETE FROM _timescaledb_config.bgw_job WHERE TRUE;
+DELETE FROM _timescaledb_catalog.bgw_job WHERE TRUE;
 TRUNCATE _timescaledb_internal.bgw_job_stat;
 
 \c :TEST_DBNAME :ROLE_DEFAULT_PERM_USER
@@ -193,10 +193,10 @@ SELECT ts_bgw_db_scheduler_test_wait_for_scheduler_finish();
 --
 \c :TEST_DBNAME :ROLE_SUPERUSER
 TRUNCATE bgw_log;
-ALTER SEQUENCE _timescaledb_config.bgw_job_id_seq RESTART;
+ALTER SEQUENCE _timescaledb_catalog.bgw_job_id_seq RESTART;
 SELECT ts_bgw_params_reset_time();
 SELECT insert_job('test_job_1', 'bgw_test_job_1', INTERVAL '100ms', INTERVAL '100s', INTERVAL '1s');
-select * from _timescaledb_config.bgw_job;
+select * from _timescaledb_catalog.bgw_job;
 \c :TEST_DBNAME :ROLE_DEFAULT_PERM_USER
 
 --Tests that the scheduler start a job right away if it's the first time and there is no job_stat entry for it
@@ -232,7 +232,7 @@ SELECT * FROM sorted_bgw_log;
 TRUNCATE bgw_log;
 TRUNCATE _timescaledb_internal.bgw_job_stat;
 SELECT ts_bgw_params_reset_time();
-DELETE FROM _timescaledb_config.bgw_job;
+DELETE FROM _timescaledb_catalog.bgw_job;
 SELECT insert_job('test_job_2', 'bgw_test_job_2_error', INTERVAL '100ms', INTERVAL '100s', INTERVAL '100ms') AS test_job_2_id \gset
 \c :TEST_DBNAME :ROLE_DEFAULT_PERM_USER
 
@@ -289,7 +289,7 @@ SELECT * FROM sorted_bgw_log;
 TRUNCATE bgw_log;
 TRUNCATE _timescaledb_internal.bgw_job_stat;
 SELECT ts_bgw_params_reset_time();
-DELETE FROM _timescaledb_config.bgw_job;
+DELETE FROM _timescaledb_catalog.bgw_job;
 --set timeout lower than job length
 SELECT insert_job('test_job_3_long', 'bgw_test_job_3_long', INTERVAL '5000ms', INTERVAL '20ms', INTERVAL '50ms');
 \c :TEST_DBNAME :ROLE_DEFAULT_PERM_USER
@@ -307,7 +307,7 @@ SELECT * FROM sorted_bgw_log;
 TRUNCATE bgw_log;
 TRUNCATE _timescaledb_internal.bgw_job_stat;
 SELECT ts_bgw_params_reset_time();
-DELETE FROM _timescaledb_config.bgw_job;
+DELETE FROM _timescaledb_catalog.bgw_job;
 --set timeout to 0
 SELECT insert_job('test_job_3_long', 'bgw_test_job_3_long', INTERVAL '5000ms', INTERVAL '0', INTERVAL '10ms');
 \c :TEST_DBNAME :ROLE_DEFAULT_PERM_USER
@@ -327,7 +327,7 @@ SELECT ts_bgw_params_mock_wait_returns_immediately(:WAIT_ON_JOB);
 TRUNCATE bgw_log;
 SELECT ts_bgw_params_reset_time();
 TRUNCATE _timescaledb_internal.bgw_job_stat;
-DELETE FROM _timescaledb_config.bgw_job;
+DELETE FROM _timescaledb_catalog.bgw_job;
 SELECT insert_job('test_job_3_long', 'bgw_test_job_3_long', INTERVAL '5000ms', INTERVAL '100s', INTERVAL '500ms');
 \c :TEST_DBNAME :ROLE_DEFAULT_PERM_USER
 
@@ -354,7 +354,7 @@ SELECT * FROM sorted_bgw_log;
 TRUNCATE bgw_log;
 SELECT ts_bgw_params_reset_time();
 TRUNCATE _timescaledb_internal.bgw_job_stat;
-DELETE FROM _timescaledb_config.bgw_job;
+DELETE FROM _timescaledb_catalog.bgw_job;
 
 SELECT ts_bgw_params_mock_wait_returns_immediately(:WAIT_FOR_STANDARD_WAITLATCH);
 SELECT ts_bgw_db_scheduler_test_run(-1);
@@ -384,7 +384,7 @@ SELECT ts_bgw_params_mock_wait_returns_immediately(:WAIT_ON_JOB);
 TRUNCATE bgw_log;
 TRUNCATE _timescaledb_internal.bgw_job_stat;
 SELECT ts_bgw_params_reset_time();
-DELETE FROM _timescaledb_config.bgw_job;
+DELETE FROM _timescaledb_catalog.bgw_job;
 SELECT insert_job('test_job_3_long', 'bgw_test_job_3_long', INTERVAL '5000ms', INTERVAL '100s', INTERVAL '10ms');
 
 SELECT ts_bgw_db_scheduler_test_run(500);
@@ -456,7 +456,7 @@ $BODY$;
 TRUNCATE bgw_log;
 TRUNCATE _timescaledb_internal.bgw_job_stat;
 SELECT ts_bgw_params_reset_time();
-DELETE FROM _timescaledb_config.bgw_job;
+DELETE FROM _timescaledb_catalog.bgw_job;
 SELECT ts_bgw_params_mock_wait_returns_immediately(:WAIT_FOR_OTHER_TO_ADVANCE);
 --Our normal limit is 8 jobs (1 already taken up by the launcher, we don't register the test scheduler)
 --so start 8 workers. Make the schedule_INTERVAL long and the retry period short so that the
@@ -500,9 +500,9 @@ TRUNCATE bgw_log;
 TRUNCATE _timescaledb_internal.bgw_job_stat;
 SELECT ts_bgw_params_reset_time();
 SELECT ts_bgw_params_mock_wait_returns_immediately(:WAIT_ON_JOB);
-DELETE FROM _timescaledb_config.bgw_job;
+DELETE FROM _timescaledb_catalog.bgw_job;
 SELECT insert_job('test_job_4', 'bgw_test_job_4', INTERVAL '100ms', INTERVAL '100s', INTERVAL '1s');
-select * from _timescaledb_config.bgw_job;
+select * from _timescaledb_catalog.bgw_job;
 \c :TEST_DBNAME :ROLE_DEFAULT_PERM_USER
 
 -- Now run and make sure next_start is 200ms away, not 100ms
@@ -553,8 +553,8 @@ DECLARE
     num_jobs INTEGER;
     num_jobs_in_list INTEGER;
 BEGIN
-    SELECT COUNT(*) from _timescaledb_config.bgw_job INTO num_jobs;
-	select COUNT(*) from ts_test_job_refresh() JOIN _timescaledb_config.bgw_job USING (id,application_name,schedule_interval,max_runtime,max_retries,retry_period) INTO num_jobs_in_list;
+    SELECT COUNT(*) from _timescaledb_catalog.bgw_job INTO num_jobs;
+	select COUNT(*) from ts_test_job_refresh() JOIN _timescaledb_catalog.bgw_job USING (id,application_name,schedule_interval,max_runtime,max_retries,retry_period) INTO num_jobs_in_list;
 	IF (num_jobs = num_jobs_in_list) THEN
 		RETURN true;
 	END IF;
@@ -583,7 +583,7 @@ $BODY$;
 select * from verify_refresh_correct();
 -- Should return the same table
 select * from verify_refresh_correct();
-DELETE FROM _timescaledb_config.bgw_job;
+DELETE FROM _timescaledb_catalog.bgw_job;
 -- Make sure jobs list is empty
 select count(*) from ts_test_job_refresh();
 
@@ -593,17 +593,17 @@ insert_job('test_2', 'bgw_test_job_1', INTERVAL '100ms', INTERVAL '100s', INTERV
 insert_job('test_3', 'bgw_test_job_1', INTERVAL '100ms', INTERVAL '100s', INTERVAL '1s');
 select * from verify_refresh_correct();
 
-DELETE from _timescaledb_config.bgw_job where application_name='test_2';
+DELETE from _timescaledb_catalog.bgw_job where application_name='test_2';
 SELECT insert_job('test_4', 'bgw_test_job_1', INTERVAL '100ms', INTERVAL '100s', INTERVAL '1s');
 select * from verify_refresh_correct();
 
-DELETE FROM _timescaledb_config.bgw_job;
+DELETE FROM _timescaledb_catalog.bgw_job;
 SELECT insert_job('test_10', 'test_10', INTERVAL '100ms', INTERVAL '100s', INTERVAL '1s');
 select * from verify_refresh_correct();
 -- Should be idempotent
 select * from verify_refresh_correct();
 
-DELETE FROM _timescaledb_config.bgw_job;
+DELETE FROM _timescaledb_catalog.bgw_job;
 SELECT
 insert_job('another', 'bgw_test_job_1', INTERVAL '100ms', INTERVAL '100s', INTERVAL '1s'),
 insert_job('another1', 'bgw_test_job_1', INTERVAL '100ms', INTERVAL '100s', INTERVAL '1s'),
@@ -612,14 +612,14 @@ insert_job('another3', 'bgw_test_job_1', INTERVAL '100ms', INTERVAL '100s', INTE
 insert_job('another4', 'bgw_test_job_1', INTERVAL '100ms', INTERVAL '100s', INTERVAL '1s');
 select * from verify_refresh_correct();
 
-DELETE FROM _timescaledb_config.bgw_job where application_name='another' OR application_name='another3';
+DELETE FROM _timescaledb_catalog.bgw_job where application_name='another' OR application_name='another3';
 SELECT insert_job('blah', 'bgw_test_job_1', INTERVAL '100ms', INTERVAL '100s', INTERVAL '1s');
 select * from verify_refresh_correct();
 
 -- Now test a real scheduler-mock running in a loop and updating the list of jobs
 TRUNCATE _timescaledb_internal.bgw_job_stat;
 SELECT ts_bgw_params_reset_time();
-DELETE FROM _timescaledb_config.bgw_job;
+DELETE FROM _timescaledb_catalog.bgw_job;
 SELECT ts_bgw_params_mock_wait_returns_immediately(:WAIT_FOR_OTHER_TO_ADVANCE);
 
 SELECT ts_bgw_db_scheduler_test_run(500);
@@ -640,7 +640,7 @@ SELECT wait_for_job_1_to_run(2);
 \x on
 select * from _timescaledb_internal.bgw_job_stat;
 \x off
-SELECT delete_job(x.id) FROM (select * from _timescaledb_config.bgw_job) x;
+SELECT delete_job(x.id) FROM (select * from _timescaledb_catalog.bgw_job) x;
 
 -- test null handling in delete_job
 SELECT delete_job(NULL);
@@ -682,8 +682,8 @@ TRUNCATE bgw_log;
 TRUNCATE _timescaledb_internal.bgw_job_stat;
 SELECT ts_bgw_params_reset_time();
 SELECT ts_bgw_params_mock_wait_returns_immediately(:WAIT_ON_JOB);
-DELETE FROM _timescaledb_config.bgw_job;
-INSERT INTO _timescaledb_config.bgw_job(application_name, schedule_interval, max_runtime, max_retries, retry_period, proc_schema, proc_name) VALUES('bgw_test_job_2_error', INTERVAL '5000ms', INTERVAL '20ms', 0, INTERVAL '20ms', 'public', 'bgw_test_job_2_error') RETURNING id;
+DELETE FROM _timescaledb_catalog.bgw_job;
+INSERT INTO _timescaledb_catalog.bgw_job(application_name, schedule_interval, max_runtime, max_retries, retry_period, proc_schema, proc_name) VALUES('bgw_test_job_2_error', INTERVAL '5000ms', INTERVAL '20ms', 0, INTERVAL '20ms', 'public', 'bgw_test_job_2_error') RETURNING id;
 \c :TEST_DBNAME :ROLE_DEFAULT_PERM_USER
 
 -- Run the first time
