@@ -115,7 +115,7 @@ ORDER BY job_id;
 
 DELETE FROM _timescaledb_internal.bgw_job_stat;
 DELETE FROM _timescaledb_internal.bgw_job_stat_history;
-DELETE FROM _timescaledb_config.bgw_job CASCADE;
+DELETE FROM _timescaledb_catalog.bgw_job CASCADE;
 
 SELECT _timescaledb_functions.start_background_workers();
 
@@ -150,7 +150,7 @@ DECLARE
 BEGIN
   RAISE INFO 'Waiting for the % jobs to run', njobs;
   SET LOCAL client_min_messages TO WARNING;
-  PERFORM test.wait_for_job_to_run_or_fail(id) FROM _timescaledb_config.bgw_job WHERE id >= 1000;
+  PERFORM test.wait_for_job_to_run_or_fail(id) FROM _timescaledb_catalog.bgw_job WHERE id >= 1000;
 END;
 $TEST$;
 
