@@ -282,7 +282,7 @@ FROM cagg, devices
 WHERE devices.device_id = cagg.thermo_id
 GROUP BY 1;
 
-SELECT * FROM cagg_on_cagg;
+SELECT * FROM cagg_on_cagg ORDER BY bucket;
 
 DROP MATERIALIZED VIEW cagg_on_cagg CASCADE;
 
@@ -295,7 +295,7 @@ FROM cagg JOIN devices
 ON devices.device_id = cagg.thermo_id
 GROUP BY 1;
 
-SELECT * FROM cagg_on_cagg_join;
+SELECT * FROM cagg_on_cagg_join ORDER BY bucket;
 
 DROP MATERIALIZED VIEW cagg_on_cagg_join CASCADE;
 
