@@ -2,7 +2,7 @@
 -- Please see the included NOTICE for copyright information and
 -- LICENSE-TIMESCALE for a copy of the license.
 
-SET timescaledb.enable_transparent_decompression to OFF;
+SET timescaledb.enable_columnarscan to OFF;
 SET timezone TO 'America/Los_Angeles';
 
 \set PREFIX 'EXPLAIN (analyze, verbose, buffers off, costs off, timing off, summary off)'
@@ -28,10 +28,10 @@ SELECT count(*) from foo;
 alter table foo set (timescaledb.compress, timescaledb.compress_segmentby = 'a,b', timescaledb.compress_orderby = 'c desc, d asc nulls last');
 
 --test self-refencing updates
-SET timescaledb.enable_transparent_decompression to ON;
+SET timescaledb.enable_columnarscan to ON;
 update foo set c = 40
 where  a = (SELECT max(a) FROM foo);
-SET timescaledb.enable_transparent_decompression to OFF;
+SET timescaledb.enable_columnarscan to OFF;
 
 SELECT id, schema_name, table_name, compression_state as compressed, compressed_hypertable_id FROM _timescaledb_catalog.hypertable ORDER BY id;
 SELECT * FROM _timescaledb_catalog.compression_settings ORDER BY relid::regclass;
@@ -211,7 +211,7 @@ FROM _timescaledb_catalog.chunk ch1, _timescaledb_catalog.hypertable ht where ch
 
 -- test plans get invalidated when chunks get compressed
 
-SET timescaledb.enable_transparent_decompression TO ON;
+SET timescaledb.enable_columnarscan TO ON;
 CREATE TABLE plan_inval(time timestamptz, device_id int);
 SELECT create_hypertable('plan_inval','time');
 ALTER TABLE plan_inval SET (timescaledb.compress,timescaledb.compress_orderby='time desc');
@@ -1245,3 +1245,18 @@ SELECT compress_chunk(show_chunks('badly_compressed_ht'));
 
 RESET timescaledb.enable_compression_ratio_warnings;
 
+CREATE TABLE test_xid_compressed(time timestamptz not null, device int, value int);
+SELECT create_hypertable('test_xid_compressed', 'time');
+INSERT INTO test_xid_compressed VALUES ('2020-01-01', 1, 1);
+ALTER TABLE test_xid_compressed SET (timescaledb.compress, timescaledb.compress_segmentby='device');
+SELECT compress_chunk(show_chunks('test_xid_compressed'));
+
+SELECT show_chunks('test_xid_compressed') AS chunk LIMIT 1 \gset
+BEGIN;
+SELECT txid_current_if_assigned() IS NULL;
+SELECT COUNT(*) FROM :chunk;
+SELECT txid_current_if_assigned() IS NULL;
+COMMIT;
+
+DROP TABLE test_xid_compressed;
+
